@@ -168,3 +168,10 @@ void CleaN900::on_pushCard_clicked()
     process.start("sh card.sh");
     process.waitForFinished();
 }
+
+void CleaN900::on_pushUpTem_clicked()
+{
+    QProcess process;
+    process.start("sh uptemp.sh");
+    process.waitForFinished();
+}
